
/*= < Fluke 45 Digital Multimeter> Include File =============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __fl45_HEADER
#define __fl45_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Define Instrument Specific Error Codes Here =============================*/
/*****************************************************************************/
#define VI_ERROR_FILE_OPEN (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_FILE_WRITE (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INTERPRETING_RESPONSE (_VI_ERROR+0x3FFC0803L)

#define VI_ERROR_INSTRUMENT_ERROR (_VI_ERROR+0x3FFC0900L)
#define VI_ERROR_CONFIGURE_ERROR (_VI_ERROR+0x3FFC0901L)
#define VI_ERROR_CONFIGURE_RANGE (_VI_ERROR+0x3FFC0902L)
#define VI_ERROR_CONFIGURE_COMPARE (_VI_ERROR+0x3FFC0905L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC fl45_init (ViRsrc resourceName, ViBoolean IDQuery, ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC fl45_applicReadMeas (ViSession instrSession, ViBoolean rdOnly, ViInt16 setPrimaryDisplay, ViInt16 setSecondaryDisplay, ViPReal64 readPrimaryDisplay, ViPReal64 readSecondaryDisplay);
ViStatus _VI_FUNC fl45_configMeas (ViSession instrSession, ViInt16 primaryDisplay, ViInt16 secondaryDisplay);
ViStatus _VI_FUNC fl45_configRange (ViSession instrSession, ViBoolean range, ViInt16 sensitivity);
ViStatus _VI_FUNC fl45_configTrig (ViSession instrSession, ViInt16 trigger, ViInt16 rate);
ViStatus _VI_FUNC fl45_configCompare (ViSession instrSession, ViBoolean compare, ViReal64 compareLow, ViReal64 compareHi);
ViStatus _VI_FUNC fl45_configHold (ViSession instrSession, ViBoolean hold, ViInt16 holdThreshold);
ViStatus _VI_FUNC fl45_configDecibel (ViSession instrSession, ViInt16 decibel, ViInt16 referenceImpedanceohms);
ViStatus _VI_FUNC fl45_configRelative (ViSession instrSession, ViInt16 relative, ViReal64 baseSet);
ViStatus _VI_FUNC fl45_configMinMax (ViSession instrSession, ViInt16 minMax, ViReal64 minSet, ViReal64 maxSet);
ViStatus _VI_FUNC fl45_trigger (ViSession instrSession);
ViStatus _VI_FUNC fl45_measCompare (ViSession instrSession, ViChar compareOutput[], ViInt16 *integerOutput);
ViStatus _VI_FUNC fl45_measPrimDisp (ViSession instrSession, ViBoolean output, ViReal64 *primaryDisplay);
ViStatus _VI_FUNC fl45_measSecDisp (ViSession instrSession, ViBoolean output, ViReal64 *secondaryDisplay);

/** INSERT USER-CALLABLE INSTRUMENT-DEPENDENT FUNCTION DECLARATIONS HERE **/

ViStatus _VI_FUNC fl45_writeInstrData (ViSession instrSession, ViString writeBuffer);
ViStatus _VI_FUNC fl45_readInstrData (ViSession instrSession, ViInt16 numberBytesToRead, ViChar readBuffer[], ViPInt32 numBytesRead);
ViStatus _VI_FUNC fl45_reset (ViSession instrSession);
ViStatus _VI_FUNC fl45_selfTest (ViSession instrSession, ViPInt16 selfTestResult, ViChar selfTestMessage[]);
ViStatus _VI_FUNC fl45_errorQuery (ViSession instrSession, ViPInt32 errorCode, ViChar errorMessage[]);
ViStatus _VI_FUNC fl45_errorMessage (ViSession instrSession, ViStatus errorCode, ViChar errorMessage[]);
ViStatus _VI_FUNC fl45_revisionQuery (ViSession instrSession, ViChar driverRevision[], ViChar firmwareRevision[]);
ViStatus _VI_FUNC fl45_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
