
/*= <HP 53131/2 Universal Counter > Include File ============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __hp5313xa_HEADER
#define __hp5313xa_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Define Instrument Specific Error Codes Here =============================*/
/*****************************************************************************/
#define VI_ERROR_FILE_OPEN (_VI_ERROR+0x3FFF0800L)
#define VI_ERROR_FILE_WRITE (_VI_ERROR+0x3FFF0801L)
#define VI_ERROR_INTERPRETING_RESPONSE (_VI_ERROR+0x3FFF0803L)
#define VI_SYSTEM_ERROR (_VI_ERROR+0x3FFF0804L)
#define VI_ERROR_UPLOW_LIMIT (_VI_ERROR+0x3FFF0805L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC hp5313xa_init (ViRsrc resourceName, ViBoolean IDQuery,
                        ViBoolean resetDevice, ViInt16 instrumentModel,
                        ViSession *instrumentHandle);
ViStatus _VI_FUNC hp5313xa_inputCond (ViSession instrumentHandle, ViInt16 channel,
                             ViBoolean coupling, ViBoolean impedanceOhms,
                             ViBoolean attenuation, ViBoolean filter);
ViStatus _VI_FUNC hp5313xa_trigSens (ViSession instrumentHandle, ViInt16 channel,
                            ViBoolean triggerLevel, ViReal64 voltageLevel,
                            ViBoolean attenuation, ViBoolean triggerSlope,
                            ViInt16 sensitivity);
ViStatus _VI_FUNC hp5313xa_limit (ViSession instrumentHandle, ViBoolean limitTest,
                         ViBoolean onFail, ViBoolean show, ViReal64 lowerLimit,
                         ViReal64 upperLimit);
ViStatus _VI_FUNC hp5313xa_math (ViSession instrumentHandle, ViBoolean math,
                        ViReal64 scaleValue, ViReal64 offsetValue);                            
ViStatus _VI_FUNC hp5313xa_savRecSet (ViSession instrumentHandle, ViBoolean saveRecall,
                             ViInt16 memoryLocation);
ViStatus _VI_FUNC hp5313xa_freqPeriodRatio (ViSession instrumentHandle,
                                   ViInt16 selectFunction, ViInt16 selectArming,
                                   ViReal64 timeDigits, ViBoolean startSlope,
                                   ViInt16 stop);
ViStatus _VI_FUNC hp5313xa_phase (ViSession instrHandle, ViBoolean selectArming,
                         ViBoolean startSlope);
ViStatus _VI_FUNC hp5313xa_totalize (ViSession instrumentHandle, ViInt16 selectArming,
                            ViReal64 timeValue, ViBoolean startSlope, ViInt16 stop);
ViStatus _VI_FUNC hp5313xa_timWidDuty (ViSession instrumentHandle, ViInt16 selectfunction,
                              ViBoolean selectArming, ViBoolean startSlope);
ViStatus _VI_FUNC hp5313xa_timeInterval (ViSession instrumentHandle, ViBoolean startArming,
                                ViBoolean startSlope, ViBoolean stop,
                                ViReal64 timeValue, ViBoolean commonMode);
ViStatus _VI_FUNC hp5313xa_confblock (ViSession instrumentHandle, ViBoolean statistics,
                             ViInt32 ofMeasurements, ViBoolean filterData,
                             ViInt16 show, ViReal64 lowerLimit, ViReal64 upperLimit);
ViStatus _VI_FUNC hp5313xa_strStpMeas (ViSession instrumentHandle, ViInt16 executionMode);
ViStatus _VI_FUNC hp5313xa_initReg (ViSession instrumentHandle);
ViStatus _VI_FUNC hp5313xa_setSrqCond (ViSession instrumentHandle, ViInt16 SRQCondition);
ViStatus _VI_FUNC hp5313xa_waitSrq (ViSession instrumentHandle);
ViStatus _VI_FUNC hp5313xa_confFunc (ViSession instrumentHandle, ViInt16 selectFunction);
ViStatus _VI_FUNC hp5313xa_initMeas (ViSession instrumentHandle);
ViStatus _VI_FUNC hp5313xa_postProcess (ViSession instrumentHandle, ViInt16 postProcess);
ViStatus _VI_FUNC hp5313xa_queryMeas (ViSession instrumentHandle, ViInt16 selectFunction,
                             ViInt16 selectMeasMethod, ViReal64 *measuredValue);
ViStatus _VI_FUNC hp5313xa_dataRes (ViSession instrumentHandle, ViReal64 *measuredData);
ViStatus _VI_FUNC hp5313xa_mathRes (ViSession instrumentHandle, ViReal64 *scaledOffsetData);
ViStatus _VI_FUNC hp5313xa_limitRes (ViSession instrumentHandle, ViInt16 *dataWithinLimit,
                            ViInt16 *failCount, ViInt16 *passCount,
                            ViInt16 *lowerFailures, ViInt16 *upperFailures);
ViStatus _VI_FUNC hp5313xa_statisticsRes (ViSession instrumentHandle, ViReal64 *mean,
                                 ViReal64 *stdDeviation, ViReal64 *maximum,
                                 ViReal64 *minimum);
ViStatus _VI_FUNC hp5313xa_queryChan3 (ViSession instrumentHandle, ViBoolean *inputCoupling,
                              ViBoolean *inputImpedance);
ViStatus _VI_FUNC hp5313xa_enaDisSet (ViSession instrumentHandle, ViBoolean limitTest,
                             ViBoolean math, ViBoolean filterData,
                             ViBoolean statistics);
ViStatus _VI_FUNC hp5313xa_writeInstrData (ViSession instrSession, ViString writeBuffer);
ViStatus _VI_FUNC hp5313xa_readInstrData (ViSession instrSession, ViInt16 numberBytesToRead, ViChar _VI_FAR readBuffer[], ViPInt32 numBytesRead);
ViStatus _VI_FUNC hp5313xa_reset (ViSession instrSession);
ViStatus _VI_FUNC hp5313xa_selfTest (ViSession instrSession, ViPInt16 selfTestResult, ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC hp5313xa_errorQuery (ViSession instrSession, ViPInt32 errorCode, ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC hp5313xa_errorMessage (ViSession instrSession, ViStatus errorCode, ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC hp5313xa_revisionQuery (ViSession instrSession, ViChar _VI_FAR driverRevision[], ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC hp5313xa_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
