
/*= Tektronix TKTDS3xx Oscilloscope Include File ============================*/

#ifndef __TKTDS3xx_HEADER
#define __TKTDS3xx_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Define Instrument Specific Error Codes Here =============================*/
/*****************************************************************************/
#define VI_ERROR_FILE_OPEN (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_FILE_WRITE (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INTERPRETING_RESPONSE (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_REF_NOT_EXIST (_VI_ERROR+0x3FFC0804L)
#define VI_ERROR_FILE_CLOSE (_VI_ERROR+0x3FFC0805L) 
#define VI_ERROR_FILE_EXISTS (_VI_ERROR+0x3FFC0806L)
#define VI_ERROR_PARAMETER9 (_VI_ERROR+0x3FFC0809L)    
#define VI_ERROR_PARAMETER10 (_VI_ERROR+0x3FFC0810L)    

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC TKTDS3xx_init (ViRsrc resourceName, ViBoolean IDQuery, ViBoolean resetDevice,
                      ViSession *instrSession);
ViStatus _VI_FUNC TKTDS3xx_configWaveformDisplay (ViSession instrSession,
                                       ViInt16 displaySource,
                                       ViBoolean displayOnOff);
ViStatus _VI_FUNC TKTDS3xx_AutoSetup (ViSession instrSession);
ViStatus _VI_FUNC TKTDS3xx_configVertical (ViSession instrSession, ViInt16 source,
                                ViReal64 voltsDiv, ViReal64 offset,
                                ViReal64 position, ViInt16 coupling,
                                ViBoolean bandwidth, ViBoolean invert);
ViStatus _VI_FUNC TKTDS3xx_configHorizontal (ViSession instrSession, ViInt16 timeBase,
                                  ViReal64 mainScale, ViInt16 position,
                                  ViReal64 delayedScale);
ViStatus _VI_FUNC TKTDS3xx_configHorizontalDelay (ViSession instrSession,
                                       ViReal64 delayTime);
ViStatus _VI_FUNC TKTDS3xx_configMainTrigger (ViSession instrSession, ViBoolean mode,
                                   ViReal64 holdoff, ViInt16 position,
                                   ViInt16 userDefinedPos);
ViStatus _VI_FUNC TKTDS3xx_configTriggerEdge (ViSession instrSession, ViInt16 source,
                                   ViInt16 coupling, ViBoolean slope, ViInt16 level,
                                   ViReal64 userDefinedLevel);
ViStatus _VI_FUNC TKTDS3xx_configTriggerVideo (ViSession instrSession, ViInt16 source,
                                    ViInt16 field, ViBoolean triggerMode,
                                    ViReal64 holdoff);
ViStatus _VI_FUNC TKTDS3xx_configAcquire (ViSession instrSession, ViInt16 mode,
                               ViBoolean stopCondition, ViInt16 envelopeAcq,
                               ViInt16 averageAcq);
ViStatus _VI_FUNC TKTDS3xx_configMath (ViSession instrSession, ViInt16 mathFunction);
ViStatus _VI_FUNC TKTDS3xx_configMeasurement (ViSession instrSession,
                                   ViBoolean highLowSetup, ViBoolean gating,
                                   ViBoolean units, ViReal64 highReference,
                                   ViReal64 midReference, ViReal64 lowReference);
ViStatus _VI_FUNC TKTDS3xx_forceTrig (ViSession instrSession);
ViStatus _VI_FUNC TKTDS3xx_acquisitionRun (ViSession instrSession, ViBoolean acquire);
ViStatus _VI_FUNC TKTDS3xx_readMeasurement (ViSession instrSession, ViInt16 measurement,
                                 ViInt16 source, ViReal64 *reading);
ViStatus _VI_FUNC TKTDS3xx_numberAcq (ViSession instrSession, ViInt16 *acquisitionCount);
ViStatus _VI_FUNC TKTDS3xx_readWvfmArray (ViSession instrSession, ViInt16 source,
                               ViInt16 start, ViInt16 stop,
                               ViReal64 waveformArray[], ViInt16 *returnPoints,
                               ViReal64 *XStart, ViReal64 *XIncrement);
ViStatus _VI_FUNC TKTDS3xx_storeWvfmFile (ViSession instrSession, ViInt16 source,
                               ViChar fileName[], ViBoolean overwriteFile);
ViStatus _VI_FUNC TKTDS3xx_readWvfmFile (ViChar fileName[], ViInt16 startingPoint,
                              ViInt16 endingPoint, ViReal64 waveformArray[],
                              ViInt16 *returnPoints, ViReal64 *XStart,
                              ViReal64 *XIncrement);
ViStatus _VI_FUNC TKTDS3xx_storeWvfmMemory (ViSession instrSession, ViInt16 source,
                                 ViInt16 destination);
ViStatus _VI_FUNC TKTDS3xx_readWvfmMemory (ViSession instrSession, ViChar fileName[],
                                ViInt16 destination);
ViStatus _VI_FUNC TKTDS3xx_readWvfm2int (ViSession instrSession, ViInt16 source,
                              ViInt16 start, ViInt16 stop, ViInt16 waveformArray[],
                              ViInt16 *returnPoints, ViReal64 *XStart,
                              ViReal64 *XIncrement, ViReal64 *YGain,
                              ViReal64 *YOffset);
ViStatus _VI_FUNC TKTDS3xx_readFile2int (ViChar fileName[], ViInt16 start, ViInt16 stop,
                              ViInt16 waveformArray[], ViInt16 *returnPoints,
                              ViReal64 *XStart, ViReal64 *XIncrement,
                              ViReal64 *YGain, ViReal64 *YOffset);
ViStatus _VI_FUNC TKTDS3xx_int2realWvfm (ViInt16 integerWvfmArray[], ViInt16 arraySize,
                              ViInt16 start, ViInt16 stop, ViReal64 YGain,
                              ViReal64 YOffset, ViInt16 *returnPoints,
                              ViReal64 wvfmDoubleArray[]);
ViStatus _VI_FUNC TKTDS3xx_configDisplay (ViSession instrSession, ViInt16 style,
                               ViReal64 accumalateTime, ViInt16 overallIntensity,
                               ViBoolean textGratIntensity, ViBoolean wvfmIntensity,
                               ViInt16 contrast, ViBoolean format,
                               ViBoolean graticule, ViBoolean triggerDisplay);
ViStatus _VI_FUNC TKTDS3xx_saveSetup (ViSession instrSession, ViBoolean setupLocation,
                           ViChar fileName[], ViInt16 instrumentSetup,
                           ViBoolean overwriteFile);
ViStatus _VI_FUNC TKTDS3xx_recallSetup (ViSession instrSession, ViBoolean setupLocation,
                             ViInt16 instrumentLocation, ViChar fileName[]);
ViStatus _VI_FUNC TKTDS3xx_gotoLocal (ViSession instrSession);
ViStatus _VI_FUNC TKTDS3xx_hardcopy (ViSession instrSession, ViInt16 format,
                          ViBoolean layout, ViBoolean port, ViChar fileName[],
                          ViBoolean clearMenus);
ViStatus _VI_FUNC TKTDS3xx_signalPathCal (ViSession instrSession);
ViStatus _VI_FUNC TKTDS3xx_writeInstrData (ViSession instrSession, ViString writeBuffer);
ViStatus _VI_FUNC TKTDS3xx_readInstrData (ViSession instrSession,
                               ViInt16 numberBytesToRead, ViChar readBuffer[],
                               ViInt32 *numBytesRead);
ViStatus _VI_FUNC TKTDS3xx_reset (ViSession instrSession);
ViStatus _VI_FUNC TKTDS3xx_selfTest (ViSession instrSession, ViInt16 *selfTestResult);
ViStatus _VI_FUNC TKTDS3xx_errorQuery (ViSession instrSession, ViInt32 *errorCode,
                            ViChar errorMessage[]);
ViStatus _VI_FUNC TKTDS3xx_errorMessage (ViSession instrSession, ViStatus errorCode,
                              ViChar errorMessage[]);
ViStatus _VI_FUNC TKTDS3xx_revisionQuery (ViSession instrSession,
                               ViChar instrumentDriverRevision[],
                               ViChar firmwareRevision[]);
ViStatus _VI_FUNC TKTDS3xx_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
